datastructuretools.ObjectInventory
==================================

.. inheritance-diagram:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory
   :private-bases:

.. autoclass:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.name

Methods
-------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.append

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.extend

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__contains__

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__repr__

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
